define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "這一季",
	"field-quarter-short-relative+1": "下一季",
	"field-tue-relative+-1": "上週二",
	"field-year": "年",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "本週三",
	"field-wed-relative+1": "下週三",
	"timeFormat-short": "ah:mm",
	"field-minute": "分鐘",
	"field-month-narrow-relative+-1": "上個月",
	"field-tue-narrow-relative+0": "本週二",
	"field-tue-narrow-relative+1": "下週二",
	"field-thu-short-relative+0": "本週四",
	"field-day-short-relative+-1": "昨天",
	"dateTimeFormat-short": "{1} {0}",
	"field-thu-short-relative+1": "下週四",
	"field-day-relative+0": "今天",
	"field-day-short-relative+-2": "前天",
	"field-day-relative+1": "明天",
	"field-week-narrow-relative+0": "本週",
	"field-day-relative+2": "後天",
	"field-week-narrow-relative+1": "下週",
	"field-wed-narrow-relative+-1": "上週三",
	"dateFormatItem-EBhms": "E Bh:mm:ss",
	"field-year-narrow": "年",
	"field-era-short": "年代",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "本週二",
	"field-year-narrow-relative+1": "明年",
	"field-tue-relative+1": "下週二",
	"field-weekdayOfMonth": "每月平日",
	"field-second-short": "秒",
	"dayPeriods-format-narrow-am": "上午",
	"dateFormatItem-MMMd": "M月d日",
	"field-weekdayOfMonth-narrow": "每月平日",
	"dayPeriods-format-abbr-am": "上午",
	"field-week-relative+0": "本週",
	"field-month-relative+0": "本月",
	"field-week-relative+1": "下週",
	"field-month-relative+1": "下個月",
	"field-sun-narrow-relative+0": "本週日",
	"timeFormat-medium": "ah:mm:ss",
	"field-mon-short-relative+0": "本週一",
	"field-sun-narrow-relative+1": "下週日",
	"field-mon-short-relative+1": "下週一",
	"field-second-relative+0": "現在",
	"dateFormatItem-yyyyQQQ": "Gy年QQQ",
	"eraNames": [
		"佛曆"
	],
	"field-weekOfMonth": "週",
	"dayPeriods-standAlone-abbr-pm": "下午",
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"dateFormatItem-yyyyMd": "Gy/M/d",
	"field-day": "日",
	"field-dayOfYear-short": "年天",
	"field-year-relative+-1": "去年",
	"dayPeriods-format-wide-am": "上午",
	"field-sat-short-relative+-1": "上週六",
	"field-hour-relative+0": "這一小時",
	"dateFormatItem-yyyyMEd": "Gy/M/d（E）",
	"field-second-short-relative+0": "現在",
	"field-wed-relative+-1": "上週三",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "上週六",
	"field-second": "秒",
	"days-standAlone-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dayPeriods-standAlone-wide-pm": "下午",
	"dateFormatItem-Ehms": "E ah:mm:ss",
	"dateFormat-long": "Gy年M月d日",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-hour-short-relative+0": "這一小時",
	"field-quarter": "季",
	"field-week-short": "週",
	"field-day-narrow-relative+0": "今天",
	"field-day-narrow-relative+1": "明天",
	"field-day-narrow-relative+2": "後天",
	"quarters-standAlone-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"days-format-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"field-tue-short-relative+0": "本週二",
	"field-tue-short-relative+1": "下週二",
	"field-month-short-relative+-1": "上個月",
	"field-mon-relative+-1": "上週一",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-month": "月",
	"field-day-narrow": "日",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "分鐘",
	"field-dayperiod": "上午/下午",
	"field-sat-short-relative+0": "本週六",
	"field-sat-short-relative+1": "下週六",
	"dayPeriods-format-narrow-pm": "下午",
	"dateFormat-medium": "Gy年M月d日",
	"dateFormatItem-yyyyMMMM": "Gy年M月",
	"eraAbbr": [
		"佛曆"
	],
	"quarters-standAlone-abbr": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"dayPeriods-format-abbr-pm": "下午",
	"dateFormatItem-yyyyM": "Gy/M",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "本週一",
	"field-mon-relative+1": "下週一",
	"field-day-narrow-relative+-1": "昨天",
	"field-year-short": "年",
	"field-day-narrow-relative+-2": "前天",
	"field-quarter-relative+-1": "上一季",
	"dateFormatItem-yyyyMMMd": "Gy年M月d日",
	"field-dayperiod-narrow": "上午/下午",
	"dayPeriods-standAlone-narrow-am": "上午",
	"field-week-narrow-relative+-1": "上週",
	"days-format-short": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dayPeriods-format-wide-pm": "下午",
	"field-dayOfYear": "年天",
	"field-sat-relative+-1": "上週六",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M/d",
	"field-minute-narrow-relative+0": "這一分鐘",
	"field-hour": "小時",
	"months-format-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"dateFormat-full": "Gy年M月d日EEEE",
	"field-month-relative+-1": "上個月",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "季",
	"field-sat-narrow-relative+0": "本週六",
	"field-fri-relative+0": "本週五",
	"field-sat-narrow-relative+1": "下週六",
	"field-fri-relative+1": "下週五",
	"dateFormatItem-EBhm": "E Bh:mm",
	"field-month-narrow-relative+0": "本月",
	"field-month-narrow-relative+1": "下個月",
	"field-sun-short-relative+0": "本週日",
	"field-sun-short-relative+1": "下週日",
	"field-week-relative+-1": "上週",
	"field-quarter-short-relative+-1": "上一季",
	"field-minute-short-relative+0": "這一分鐘",
	"dateFormatItem-Ehm": "E ah:mm",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-quarter-relative+0": "這一季",
	"field-minute-relative+0": "這一分鐘",
	"timeFormat-long": "ah:mm:ss [z]",
	"field-quarter-relative+1": "下一季",
	"field-wed-short-relative+-1": "上週三",
	"dateFormat-short": "Gy/M/d",
	"dateFormatItem-Bh": "Bh時",
	"field-year-narrow-relative+-1": "去年",
	"field-thu-short-relative+-1": "上週四",
	"dateFormatItem-yyyyMMMEd": "Gy年M月d日E",
	"days-standAlone-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"field-mon-narrow-relative+-1": "上週一",
	"dateFormatItem-MMMMd": "M月d日",
	"field-thu-narrow-relative+-1": "上週四",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "上週二",
	"field-weekOfMonth-short": "週",
	"dateFormatItem-H": "H時",
	"dateFormatItem-yyyy": "Gy年",
	"dayPeriods-standAlone-narrow-pm": "下午",
	"dateFormatItem-M": "M月",
	"field-wed-short-relative+0": "本週三",
	"months-standAlone-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-wed-short-relative+1": "下週三",
	"field-sun-relative+-1": "上週日",
	"days-standAlone-abbr": [
		"週日",
		"週一",
		"週二",
		"週三",
		"週四",
		"週五",
		"週六"
	],
	"dateTimeFormat-full": "{1}{0}",
	"field-second-narrow-relative+0": "現在",
	"dateFormatItem-hm": "ah:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "週天",
	"field-day-short-relative+0": "今天",
	"field-quarter-narrow-relative+0": "這一季",
	"field-day-short-relative+1": "明天",
	"field-sat-relative+0": "本週六",
	"field-quarter-narrow-relative+1": "下一季",
	"field-day-short-relative+2": "後天",
	"field-sat-relative+1": "下週六",
	"dateFormatItem-h": "ah時",
	"field-week-short-relative+0": "本週",
	"field-week-short-relative+1": "下週",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-dayOfYear-narrow": "年天",
	"field-month-short-relative+0": "本月",
	"field-month-short-relative+1": "下個月",
	"field-weekdayOfMonth-short": "每月平日",
	"timeFormat-full": "ah:mm:ss [zzzz]",
	"dateFormatItem-MEd": "M/d（E）",
	"field-zone-narrow": "時區",
	"dateFormatItem-y": "Gy年",
	"field-thu-narrow-relative+0": "本週四",
	"field-sun-narrow-relative+-1": "上週日",
	"field-mon-short-relative+-1": "上週一",
	"field-thu-narrow-relative+1": "下週四",
	"field-thu-relative+0": "本週四",
	"field-thu-relative+1": "下週四",
	"field-fri-short-relative+-1": "上週五",
	"dateFormatItem-hms": "ah:mm:ss",
	"field-thu-relative+-1": "上週四",
	"field-week": "週",
	"quarters-format-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"dateFormatItem-Ed": "d日（E）",
	"field-wed-narrow-relative+0": "本週三",
	"field-wed-narrow-relative+1": "下週三",
	"field-quarter-narrow-relative+-1": "上一季",
	"field-year-short-relative+0": "今年",
	"dateFormatItem-yyyyMMM": "Gy年M月",
	"field-dayperiod-short": "上午/下午",
	"field-year-short-relative+1": "明年",
	"field-fri-short-relative+0": "本週五",
	"field-fri-short-relative+1": "下週五",
	"days-standAlone-short": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"field-week-short-relative+-1": "上週",
	"field-hour-narrow-relative+0": "這一小時",
	"dateFormatItem-yyyyQQQQ": "Gy年QQQQ",
	"field-hour-short": "小時",
	"field-zone-short": "時區",
	"quarters-format-abbr": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"field-month-narrow": "月",
	"field-hour-narrow": "小時",
	"field-fri-narrow-relative+-1": "上週五",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"field-era-narrow": "年代",
	"field-fri-relative+-1": "上週五",
	"eraNarrow": "佛曆",
	"dateFormatItem-Bhms": "Bh:mm:ss",
	"field-tue-short-relative+-1": "上週二",
	"field-minute-narrow": "分鐘",
	"days-format-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"field-mon-narrow-relative+0": "本週一",
	"field-mon-narrow-relative+1": "下週一",
	"field-year-short-relative+-1": "去年",
	"field-zone": "時區",
	"dateFormatItem-MMMEd": "M月d日E",
	"field-weekOfMonth-narrow": "週",
	"field-weekday-narrow": "週天",
	"field-quarter-narrow": "季",
	"field-sun-short-relative+-1": "上週日",
	"field-day-relative+-1": "昨天",
	"dayPeriods-standAlone-abbr-am": "上午",
	"field-day-relative+-2": "前天",
	"field-weekday-short": "週天",
	"days-format-abbr": [
		"週日",
		"週一",
		"週二",
		"週三",
		"週四",
		"週五",
		"週六"
	],
	"dateFormatItem-Bhm": "Bh:mm",
	"field-sun-relative+0": "本週日",
	"field-sun-relative+1": "下週日",
	"dateFormatItem-Gy": "Gy年",
	"field-day-short": "日",
	"field-week-narrow": "週",
	"field-era": "年代",
	"field-fri-narrow-relative+0": "本週五",
	"field-fri-narrow-relative+1": "下週五",
	"dayPeriods-standAlone-wide-am": "上午"
}
//end v1.x content
);